@@ -1,9 +1,8 @@
 import csv
 from urllib.request import urlopen
-import requests
 import io
 
-def _read_data(url):
+def _read_data(url: str) -> dict:
     response = urlopen(url)
     byts = response.read()
     data = io.StringIO(byts.decode())
@@ -25,8 +24,8 @@ def _convert_data(data: dict) -> dict:
             out[k] = list(map(int, data[k]))
     return out
 
-def get_hopkins() -> (dict, dict, dict):
-    datafiles = ["https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_19-covid-Confirmed.csv",
-                 "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_19-covid-Deaths.csv",
-                 "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_19-covid-Recovered.csv"]
+def get_hopkins() -> (dict, dict):
+    datafiles = ["https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_confirmed_global.csv",
+                 "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv"
+]
     return (_convert_data(_read_data(dat)) for dat in datafiles)
